@@ -141,10 +141,10 @@ namespace gum {
         */
         friend std::ostream&
         operator<<( std::ostream& out,
-                    const LpCol& col );  // calls col.toString(),
-                                         // friend is useless but
-                                         // good for documentation
-                                         // purpose
+                    const LpCol&  col );  // calls col.toString(),
+                                          // friend is useless but
+                                          // good for documentation
+                                          // purpose
 
         /// @}
 
@@ -227,9 +227,9 @@ namespace gum {
         * otherwise.
         */
         LpExpr( const LpExpr& expr,
-                bool copyLeft,
-                bool copyMiddle,
-                bool copyRight );
+                bool          copyLeft,
+                bool          copyMiddle,
+                bool          copyRight );
 
         /**
         * @brief Move copy constructor from temporary.
@@ -562,10 +562,10 @@ namespace gum {
         */
         friend std::ostream&
         operator<<( std::ostream& out,
-                    const LpRow& row );  // calls row.toString(),
-                                         // friend is useless but
-                                         // good for documentation
-                                         // purpose
+                    const LpRow&  row );  // calls row.toString(),
+                                          // friend is useless but
+                                          // good for documentation
+                                          // purpose
 
         /**
         * @brief Get the string representation of a calling row.
@@ -622,8 +622,7 @@ namespace gum {
         * @brief Copy compound assignment.
         * @param from The LpInterface to be copied.
         */
-        LpInterface<GUM_SCALAR>&
-        operator=( const LpInterface<GUM_SCALAR>& from );
+        LpInterface<GUM_SCALAR>& operator=( const LpInterface<GUM_SCALAR>& from );
 
         /**
         * @brief Move coumpound assignment.
@@ -644,7 +643,7 @@ namespace gum {
         */
         template <typename T>
         friend std::ostream& operator<<(
-            std::ostream& out,
+            std::ostream&         out,
             const LpInterface<T>& lpi );  // calls lpi.toString(), friend is
                                           // useless but good for documentation
                                           // purpose
