@@ -490,8 +490,7 @@ namespace gum {
      * @return Returns the second value of a pair given its first value or
      * default_val if first is not in the bjection.
      */
-    const T2& secondWithDefault( const T1& second,
-                                 const T2& default_val ) const;
+    const T2& secondWithDefault( const T1& second, const T2& default_val ) const;
 
     /**
      * @brief Returns true if first is the first element in a pair in the
@@ -815,8 +814,8 @@ namespace gum {
      * @return Returns the gum::Bijection in which the copy was made.
      */
     template <typename OtherAlloc>
-    BijectionImplementation<T1, T2, Alloc, true>& operator=(
-        const BijectionImplementation<T1, T2, OtherAlloc, true>& toCopy );
+    BijectionImplementation<T1, T2, Alloc, true>&
+    operator=( const BijectionImplementation<T1, T2, OtherAlloc, true>& toCopy );
 
     /**
      * @brief Move operator.
@@ -1740,16 +1739,14 @@ namespace gum {
      * @param toCompare The gum::BijectionIteratorSafe to compare.
      * @return Returns true if they differ.
      */
-    bool operator!=( const BijectionIterator<T1, T2>& toCompare ) const
-        noexcept;
+    bool operator!=( const BijectionIterator<T1, T2>& toCompare ) const noexcept;
 
     /**
      * @brief Equality operator.
      * @param toCompare The gum::BijectionIteratorSafe to compare.
      * @return Returns true if they are equal.
      */
-    bool operator==( const BijectionIterator<T1, T2>& toCompare ) const
-        noexcept;
+    bool operator==( const BijectionIterator<T1, T2>& toCompare ) const noexcept;
 
     /// @}
     // ============================================================================
@@ -1806,12 +1803,11 @@ namespace gum {
    * @tparam Alloc The allocator used for allocating memory.
    */
   template <typename T1, typename T2, typename Alloc = std::allocator<T2>>
-  class Bijection
-      : public BijectionImplementation<T1,
-                                       T2,
-                                       Alloc,
-                                       std::is_scalar<T1>::value &&
-                                           std::is_scalar<T2>::value> {
+  class Bijection : public BijectionImplementation<T1,
+                                                   T2,
+                                                   Alloc,
+                                                   std::is_scalar<T1>::value &&
+                                                       std::is_scalar<T2>::value> {
     public:
     /// types for STL compliance
     /// @{
@@ -1838,12 +1834,11 @@ namespace gum {
     /// @}
 
     /// The Implementation of this gum::Bijection.
-    using Implementation =
-        BijectionImplementation<T1,
-                                T2,
-                                Alloc,
-                                std::is_scalar<T1>::value &&
-                                    std::is_scalar<T2>::value>;
+    using Implementation = BijectionImplementation<T1,
+                                                   T2,
+                                                   Alloc,
+                                                   std::is_scalar<T1>::value &&
+                                                       std::is_scalar<T2>::value>;
 
     // ============================================================================
     /// @name Constructors/destructors
@@ -1902,8 +1897,7 @@ namespace gum {
      * @param toCopy The gum::Bijection to copy.
      * @return Returns this gum::Bijection.
      */
-    Bijection<T1, T2, Alloc>&
-    operator=( const Bijection<T1, T2, Alloc>& toCopy );
+    Bijection<T1, T2, Alloc>& operator=( const Bijection<T1, T2, Alloc>& toCopy );
 
     /**
      * @brief Generalized copy operator.
