@@ -74,12 +74,12 @@ namespace gum {
     static constexpr unsigned long gold = 2654435769UL;
     static constexpr unsigned long pi = 3373259426UL;
     static constexpr unsigned long mask = 4294967295UL;
-    static constexpr size_t offset = 32;
+    static constexpr size_t        offset = 32;
 #else  // unsigned long = 64 bits
     static constexpr unsigned long gold = 11400714819323198486UL;
     static constexpr unsigned long pi = 14488038916154245684UL;
     static constexpr unsigned long mask = 18446744073709551615UL;
-    static constexpr size_t offset = 64;
+    static constexpr size_t        offset = 64;
 #endif /* unsigned long = 32 bits */
   };
 
@@ -608,8 +608,7 @@ namespace gum {
    * @ingroup hashfunctions_group
    */
   template <>
-  class HashFunc<std::pair<int, int>> : public HashFuncSmallKeyPair<int, int> {
-  };
+  class HashFunc<std::pair<int, int>> : public HashFuncSmallKeyPair<int, int> {};
 
   /**
    * @headerfile hashFunc.h <agrum/core/hashFunc.h>
@@ -626,8 +625,8 @@ namespace gum {
    * @ingroup hashfunctions_group
    */
   template <>
-  class HashFunc<std::pair<long, long>>
-      : public HashFuncSmallKeyPair<long, long> {};
+  class HashFunc<std::pair<long, long>> : public HashFuncSmallKeyPair<long, long> {
+  };
 
   /**
    * @headerfile hashFunc.h <agrum/core/hashFunc.h>
