@@ -47,9 +47,8 @@ namespace gum {
   class MultiPriorityQueue;
 
   template <typename Val, typename Priority, typename Cmp, typename Alloc>
-  std::ostream&
-  operator<<( std::ostream&,
-              const MultiPriorityQueue<Val, Priority, Cmp, Alloc>& );
+  std::ostream& operator<<( std::ostream&,
+                            const MultiPriorityQueue<Val, Priority, Cmp, Alloc>& );
 
 #endif  // DOXYGEN_SHOULD_SKIP_THIS
 
@@ -141,8 +140,8 @@ namespace gum {
     /// @}
 
     /// The allocator for the indices.
-    using IndexAlloc = typename Alloc::template rebind<
-        std::pair<Val, std::vector<Size>>>::other;
+    using IndexAlloc =
+        typename Alloc::template rebind<std::pair<Val, std::vector<Size>>>::other;
 
     /// The allocator for the heap.
     using HeapAlloc =
@@ -163,7 +162,7 @@ namespace gum {
      * elements (could be for instance vectors or hashtables).
      */
     explicit MultiPriorityQueue(
-        Cmp compare = Cmp(),
+        Cmp  compare = Cmp(),
         Size capacity = GUM_MULTIPLE_PRIORITY_QUEUE_DEFAULT_CAPACITY );
 
     /**
