@@ -141,8 +141,7 @@ namespace gum {
      * @param from The gum::PriorityQueueImplementation to copy.
      */
     PriorityQueueImplementation(
-        const PriorityQueueImplementation<Val, Priority, Cmp, Alloc, Gen>&
-            from );
+        const PriorityQueueImplementation<Val, Priority, Cmp, Alloc, Gen>& from );
 
     /**
      * @brief Generalized copy constructor.
@@ -186,8 +185,7 @@ namespace gum {
      * @return Returns this gum::PriorityQueueImplementation.
      */
     PriorityQueueImplementation<Val, Priority, Cmp, Alloc, Gen>& operator=(
-        const PriorityQueueImplementation<Val, Priority, Cmp, Alloc, Gen>&
-            from );
+        const PriorityQueueImplementation<Val, Priority, Cmp, Alloc, Gen>& from );
 
     /**
      * @brief Generalized copy operator.
@@ -559,8 +557,7 @@ namespace gum {
      * @param from The gum::PriorityQueueImplementation to copy.
      */
     PriorityQueueImplementation(
-        const PriorityQueueImplementation<Val, Priority, Cmp, Alloc, true>&
-            from );
+        const PriorityQueueImplementation<Val, Priority, Cmp, Alloc, true>& from );
 
     /**
      * @brief Generalized copy constructor.
@@ -604,8 +601,7 @@ namespace gum {
      * @return Returns this gum::PriorityQueueImplementation.
      */
     PriorityQueueImplementation<Val, Priority, Cmp, Alloc, true>& operator=(
-        const PriorityQueueImplementation<Val, Priority, Cmp, Alloc, true>&
-            from );
+        const PriorityQueueImplementation<Val, Priority, Cmp, Alloc, true>& from );
 
     /**
      * @brief Generalized copy operator.
@@ -977,12 +973,11 @@ namespace gum {
     using allocator_type = Alloc;
     /// @}
 
-    using Implementation =
-        PriorityQueueImplementation<Val,
-                                    Priority,
-                                    Cmp,
-                                    Alloc,
-                                    std::is_scalar<Val>::value>;
+    using Implementation = PriorityQueueImplementation<Val,
+                                                       Priority,
+                                                       Cmp,
+                                                       Alloc,
+                                                       std::is_scalar<Val>::value>;
 
     // ============================================================================
     /// @name Constructors / Destructors
@@ -998,9 +993,8 @@ namespace gum {
      * @param capacity the size of the internal data structures containing the
      * elements (could be for instance vectors or hashtables).
      */
-    explicit PriorityQueue(
-        Cmp compare = Cmp(),
-        Size capacity = GUM_PRIORITY_QUEUE_DEFAULT_CAPACITY );
+    explicit PriorityQueue( Cmp  compare = Cmp(),
+                            Size capacity = GUM_PRIORITY_QUEUE_DEFAULT_CAPACITY );
 
     /**
      * @brief Initializer list constructor.
@@ -1010,8 +1004,7 @@ namespace gum {
      *
      * @param list The initializer list.
      */
-    explicit PriorityQueue(
-        std::initializer_list<std::pair<Val, Priority>> list );
+    explicit PriorityQueue( std::initializer_list<std::pair<Val, Priority>> list );
 
     /**
      * @brief Copy constructor.
