@@ -180,7 +180,6 @@ namespace gum {
     // ============================================================================
     /// @{
 
-
     /**
      * @brief Default constructor.
      *
@@ -274,6 +273,16 @@ namespace gum {
     template <typename OtherAlloc>
     bool operator!=( const Set<Key, OtherAlloc>& s2 ) const;
 
+    /**
+     * @brief Intersection update operator
+     * @tparam OtherAlloc The other gum::Set allocator.
+     * @param s2 The gum::Set to intersect.
+     * @return Returns this. Now this contains the elements belonging
+     * both to this and s2.
+     */
+    template <typename OtherAlloc>
+    const Set<Key, Alloc>& operator*=( const Set<Key, OtherAlloc>& s2 );
+
     /**
      * @brief Intersection operator.
      * @tparam OtherAlloc The other gum::Set allocator.
@@ -284,6 +293,15 @@ namespace gum {
     template <typename OtherAlloc>
     Set<Key, Alloc> operator*( const Set<Key, OtherAlloc>& s2 ) const;
 
+    /**
+     * @brief Union update operator
+     * @tparam OtherAlloc The other gum::Set allocator.
+     * @param s2 The gum::Set to update
+     * @return Returns this. Now this contains the elements belonging
+     * both to this or to s2.
+     */
+    template <typename OtherAlloc>
+    const Set<Key, Alloc>& operator+=( const Set<Key, OtherAlloc>& s2 );
 
     /**
      * @brief Union operator.
@@ -396,6 +414,18 @@ namespace gum {
      */
     bool contains( const Key& k ) const;
 
+    /**
+     * @return Returns true if *this is a strict subset of s
+     */
+    template <typename OtherAlloc>
+    bool isSubsetOf( const Set<Key, OtherAlloc>& s ) const;
+
+    /**
+     * @return Returns true if *this is a strict superset of s
+     */
+    template <typename OtherAlloc>
+    bool isSupersetOf( const Set<Key, OtherAlloc>& s ) const;
+
     /**
      * @brief Indicates whether a given elements belong to the set.
      * @return Returns true if a given elements belong to the set.
@@ -679,9 +709,8 @@ namespace gum {
      * default size is computed that is a good trade-off between space
      * consumption and efficiency of new elements insertions.
      */
-    template <
-        typename NewKey,
-        typename NewAlloc = typename Alloc::template rebind<NewKey>::other>
+    template <typename NewKey,
+              typename NewAlloc = typename Alloc::template rebind<NewKey>::other>
     HashTable<Key, NewKey, NewAlloc> hashMap( NewKey ( *f )( const Key& ),
                                               Size capacity = 0 ) const;
 
@@ -698,9 +727,8 @@ namespace gum {
      * default size is computed that is a good trade-off between space
      * consumption and efficiency of new elements insertions.
      */
-    template <
-        typename NewKey,
-        typename NewAlloc = typename Alloc::template rebind<NewKey>::other>
+    template <typename NewKey,
+              typename NewAlloc = typename Alloc::template rebind<NewKey>::other>
     HashTable<Key, NewKey, NewAlloc> hashMap( const NewKey& val,
                                               Size size = 0 ) const;
 
@@ -712,9 +740,8 @@ namespace gum {
      *
      * @param f A function that maps a Key into a NewKey
      */
-    template <
-        typename NewKey,
-        typename NewAlloc = typename Alloc::template rebind<NewKey>::other>
+    template <typename NewKey,
+              typename NewAlloc = typename Alloc::template rebind<NewKey>::other>
     List<NewKey, NewAlloc> listMap( NewKey ( *f )( const Key& ) ) const;
 
     /// @}
@@ -735,6 +762,7 @@ namespace gum {
     Set( const HashTable<Key, bool, Alloc>& h );
   };
 
+
   // ===========================================================================
   // ===                          SAFE SET ITERATORS                         ===
   // ===========================================================================
@@ -1149,11 +1177,73 @@ namespace gum {
   template <typename Key, typename Alloc>
   std::ostream& operator<<( std::ostream&, const Set<Key, Alloc>& );
 
+
+  /// the hash function for sets of int
+  template <typename Alloc>
+  class HashFunc<Set<int, Alloc>> : public HashFuncBase<Set<int, Alloc>> {
+    public:
+    /// computes the hashed value of a key
+    Size operator()( const Set<int, Alloc>& key ) const;
+  };
+
+  /// the hash function for sets of unsigned int
+  template <typename Alloc>
+  class HashFunc<Set<unsigned int, Alloc>>
+      : public HashFuncBase<Set<unsigned int, Alloc>> {
+    public:
+    /// computes the hashed value of a key
+    Size operator()( const Set<unsigned int, Alloc>& key ) const;
+  };
+
+  /// the hash function for sets of long
+  template <typename Alloc>
+  class HashFunc<Set<long, Alloc>> : public HashFuncBase<Set<long, Alloc>> {
+    public:
+    /// computes the hashed value of a key
+    Size operator()( const Set<long, Alloc>& key ) const;
+  };
+
+  /// the hash function for sets of unsigned long
+  template <typename Alloc>
+  class HashFunc<Set<unsigned long, Alloc>>
+      : public HashFuncBase<Set<unsigned long, Alloc>> {
+    public:
+    /// computes the hashed value of a key
+    Size operator()( const Set<unsigned long, Alloc>& key ) const;
+  };
+
+  /// the hash function for sets of float
+  template <typename Alloc>
+  class HashFunc<Set<float, Alloc>> : public HashFuncBase<Set<float, Alloc>> {
+    public:
+    /// computes the hashed value of a key
+    Size operator()( const Set<float, Alloc>& key ) const;
+
+    private:
+    /// used for casting floats to Size
+    typename HashFuncCastKey<float>::type __casting;
+  };
+
+  /// the hash function for sets of double
+  template <typename Alloc>
+  class HashFunc<Set<double, Alloc>> : public HashFuncBase<Set<double, Alloc>> {
+    public:
+    /// computes the hashed value of a key
+    Size operator()( const Set<double, Alloc>& key ) const;
+
+    private:
+    /// used for casting floats to Size
+    typename HashFuncCastKey<double>::type __casting;
+  };
+
+
 } /* namespace gum */
 
 
 extern template class gum::Set<int>;
 extern template class gum::Set<long>;
+extern template class gum::Set<unsigned int>;
+extern template class gum::Set<unsigned long>;
 extern template class gum::Set<float>;
 extern template class gum::Set<double>;
 extern template class gum::Set<std::string>;
