@@ -95,8 +95,7 @@ namespace gum {
     /// @{
 
     /// copy assignment operator
-    NodeGraphPartIterator&
-    operator=( const NodeGraphPartIterator& it ) noexcept;
+    NodeGraphPartIterator& operator=( const NodeGraphPartIterator& it ) noexcept;
 
     /// move assignment operator
     NodeGraphPartIterator& operator=( NodeGraphPartIterator&& it ) noexcept;
@@ -136,8 +135,7 @@ namespace gum {
    * @class NodeGraphPartIteratorSafe
    * @brief Safe iterator on the node set of a graph.
    */
-  class NodeGraphPartIteratorSafe : public NodeGraphPartIterator,
-                                    public Listener {
+  class NodeGraphPartIteratorSafe : public NodeGraphPartIterator, public Listener {
 
     friend class NodeGraphPart;
 
@@ -266,8 +264,8 @@ namespace gum {
     // something strange with SWIG (with "using", these definitions cored dump
     // the
     // swig process)
-    typedef NodeGraphPartIterator NodeIterator;
-    typedef NodeGraphPartIterator NodeConstIterator;
+    typedef NodeGraphPartIterator     NodeIterator;
+    typedef NodeGraphPartIterator     NodeConstIterator;
     typedef NodeGraphPartIteratorSafe NodeIteratorSafe;
     typedef NodeGraphPartIteratorSafe NodeConstIteratorSafe;
 
